summaryrefslogtreecommitdiffhomepage
path: root/pkg/abi/linux/tty.go
diff options
context:
space:
mode:
authorgVisor bot <gvisor-bot@google.com>2020-09-01 21:46:57 +0000
committergVisor bot <gvisor-bot@google.com>2020-09-01 21:46:57 +0000
commitdbd886176ac62b526c81fcda13da63c74d46be98 (patch)
tree95829e05bd49451d8993a7cfcbc07465a13164d2 /pkg/abi/linux/tty.go
parent302245568e5f5286ac6cce38991ea3b9a17a64b7 (diff)
parent2eaf54dd597d8aaa56ad6274e0c1e585d9b9c063 (diff)
Merge release-20200818.0-102-g2eaf54dd5 (automated)
Diffstat (limited to 'pkg/abi/linux/tty.go')
-rw-r--r--pkg/abi/linux/tty.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/pkg/abi/linux/tty.go b/pkg/abi/linux/tty.go
index 5a5ff0aa2..47e65d9fb 100644
--- a/pkg/abi/linux/tty.go
+++ b/pkg/abi/linux/tty.go
@@ -325,9 +325,9 @@ var MasterTermios = KernelTermios{
OutputSpeed: 38400,
}
-// DefaultSlaveTermios is the default terminal configuration of the slave end
-// of a Unix98 pseudoterminal.
-var DefaultSlaveTermios = KernelTermios{
+// DefaultReplicaTermios is the default terminal configuration of the replica
+// end of a Unix98 pseudoterminal.
+var DefaultReplicaTermios = KernelTermios{
InputFlags: ICRNL | IXON,
OutputFlags: OPOST | ONLCR,
ControlFlags: B38400 | CS8 | CREAD,